@@ -1,4 +1,5 @@
 import datetime
+from decimal import Decimal
 
 from conversionkit import message
 from conversionkit.exception import ConversionKitError
@@ -64,6 +65,38 @@ def unicodeToUnicode(min=None, max=None):
             conversion.result = conversion.value
     return unicodeToUnicode_converter
 
+def unicodeToDecimal(min=None, max=None, quantize=None):
+    if min is not None and max is not None and max < min:
+        raise StringConvertError(
+            'The value of max should not be smaller than the value of min'
+        )
+    def unicodeToDecimal_converter(conversion, state=None):
+        if not isinstance(conversion.value, unicode):
+            conversion.error = 'The value %r is not a Unicode object'%conversion.value
+            return 
+        value = conversion.value
+        try:
+            result = Decimal(value, 2)
+            if quantize is not None:
+                result = result.quantize(quantize)
+        # Catch *every* error
+        except Exception, e:
+            conversion.error = message(state, str(e))
+        else:
+            if min is not None and result < min:
+                conversion.error = message(
+                    state,
+                    'The number must be greater than or equal to %s'%(min,),
+                )
+            elif max is not None and result > max:
+                conversion.error = message(
+                    state,
+                    'The number must be less than or equal to %s'%(max,)
+                )
+            else:
+                conversion.result = result
+    return unicodeToDecimal_converter
+
 def unicodeToFloat(min=None, max=None):
     if min is not None and max is not None and max < min:
         raise StringConvertError(
