@@ -54,7 +54,7 @@ def unicodeToEmail(
 
     on others::
 
-        $ easy_install PyDNS
+        $ easy_install pydns
 
     """
     # Could not reproduce the API for these two tests:
@@ -68,7 +68,7 @@ def unicodeToEmail(
                 "(or the DNS package cannot be found). Domain names in "
                 "addresses cannot be resolved."
             )
-            raise ImportError("No module named DNS")
+            raise ImportError("No module named DNS, have you installed pydns?")
 
     def unicodeToEmail_converter(conversion, state=None):
         if not isinstance(conversion.value, unicode):
